@@ -19,14 +19,15 @@ class WebhookAdmin(admin.ModelAdmin):
     list_display = ['id', 'application', "endpoint_url", 'is_active', 'created_at']
     raw_id_fields = ['application', ]
     list_filter = ["is_active", "created_at", "updated_at"]
-
+    search_fields = ['application__id', 'application__name', 'endpoint_url']
 
 
 class WebhookEventPostAttemptAdmin(admin.ModelAdmin):
     ordering = ["-created_at"]
-    list_display = ['id', "status", "endpoint_url", 'created_at']
+    list_display = ['id', "status", "event", "endpoint_url", 'created_at']
     readonly_fields = list_display + ['response_data', 'event', 'application']
     list_filter = ["status", "created_at", "updated_at"]
+    search_fields = ['application__id', 'application__name', 'event__id', 'endpoint_url']
 
     def has_add_permission(self, request, obj=None):
         return False
@@ -42,10 +43,11 @@ class EventAdmin(admin.ModelAdmin):
     post_event_to_webhook.short_description = "Post the selected event(s) to webhooks"
 
     ordering = ["-created_at"]
-    list_display = ['id', "event_object", "action", "is_processed", 'application', 'created_at']
+    list_display = ['id', "event_object", "action", "is_processed", 'log', 'application', 'created_at']
     readonly_fields = list_display + ['event_data', 'application']
     list_filter = ["action", "is_processed", "created_at", "updated_at"]
     actions = [post_event_to_webhook]
+    search_fields = ['application__id', 'application__name', 'action', 'event_object', 'log__id', 'id']
 
     def has_add_permission(self, request, obj=None):
         return False
@@ -57,6 +59,7 @@ class LogAdmin(admin.ModelAdmin):
     raw_id_fields = ['application']
     readonly_fields = list_display + ['request_data', 'response_data', 'user', 'application']
     list_filter = ["status", "method", "created_at", "updated_at"]
+    search_fields = ['application__id', 'application__name', 'status', 'path', 'id', 'user__id', 'user__username']
 
     def has_add_permission(self, request, obj=None):
         return False
