@@ -32,13 +32,17 @@ class WebhookAbstract(models.Model):
 class Webhook(WebhookAbstract):
     pass
 
-class EventAbstract(models.Model):
+
+
+class LogAbstract(models.Model):
     id = models.BigAutoField(unique=True, primary_key=True)
-    application = models.ForeignKey(oauth2_settings.APPLICATION_MODEL, on_delete=models.SET_NULL, null=True, blank=True, verbose_name=_('Application'))
-    event_object = models.CharField(max_length=500, blank=True, null=True, help_text="")
-    action = models.CharField(max_length=50, blank=True, null=True, help_text="create/update/partial-update/delete etc")
-    event_data = models.JSONField(_('Event Data'), default=dict, blank=True, null=True, help_text="Payload to be sent to webhook endpoint")
-    is_processed = models.BooleanField(default=False, help_text="Whether the event has been posted to webhook endpoints or not")
+    application = models.ForeignKey(oauth2_settings.APPLICATION_MODEL, on_delete=models.SET_NULL, null=True, blank=True, verbose_name="Created By Application")
+    user = models.ForeignKey(get_user_model(), on_delete=models.SET_NULL, null=True, verbose_name=_("Users"), help_text="Activity was preformed by this user")
+    request_data = models.JSONField(_('Request Data'), default=dict, blank=True, null=True)
+    response_data = models.JSONField(_('Response Data'), default=dict, blank=True, null=True)
+    path = models.CharField(_('Path'), max_length=500, blank=False, null=False)
+    status = models.CharField(_('HTTP Status'), max_length=255, blank=False, null=False)
+    method = models.CharField(_('HTTP Method'), max_length=255, blank=False, null=False)
     created_at = models.DateTimeField(auto_now_add=True, null=True)
     updated_at = models.DateTimeField(auto_now=True, null=True)
 
@@ -46,6 +50,30 @@ class EventAbstract(models.Model):
         abstract = True
         ordering = ['-created_at']
 
+    def __str__(self):
+        return "Log ID: " + str(self.id)
+
+class Log(LogAbstract):
+    pass
+
+
+class EventAbstract(models.Model):
+    id = models.BigAutoField(unique=True, primary_key=True)
+    application = models.ForeignKey(oauth2_settings.APPLICATION_MODEL, on_delete=models.SET_NULL, null=True, blank=True, verbose_name=_('Application'))
+    event_object = models.CharField(max_length=500, blank=True, null=True, help_text="")
+    action = models.CharField(max_length=50, blank=True, null=True, help_text="create/update/partial-update/delete etc")
+    event_data = models.JSONField(_('Event Data'), default=dict, blank=True, null=True, help_text="Payload to be sent to webhook endpoint")
+    is_processed = models.BooleanField(default=False, help_text="Whether the event has been posted to webhook endpoints or not")
+    log = models.ForeignKey(Log, on_delete=models.SET_NULL, null=True, blank=True, verbose_name=_('Log'))
+    created_at = models.DateTimeField(auto_now_add=True, null=True)
+    updated_at = models.DateTimeField(auto_now=True, null=True)
+
+    class Meta:
+        abstract = True
+        ordering = ['-created_at']
+
+    def __str__(self):
+        return "Event ID: " + str(self.id)
 
 class Event(EventAbstract):
     pass
@@ -65,30 +93,13 @@ class WebhookEventPostAttemptAbstract(models.Model):
         abstract = True
         ordering = ['-created_at']
 
+    def __str__(self):
+        return "Webhook Post Attempt ID: " + str(self.id)
 
 class WebhookEventPostAttempt(WebhookEventPostAttemptAbstract):
     pass
 
 
-class LogAbstract(models.Model):
-    id = models.BigAutoField(unique=True, primary_key=True)
-    application = models.ForeignKey(oauth2_settings.APPLICATION_MODEL, on_delete=models.SET_NULL, null=True, blank=True, verbose_name="Created By Application")
-    user = models.ForeignKey(get_user_model(), on_delete=models.SET_NULL, null=True, verbose_name=_("Users"), help_text="Activity was preformed by this user")
-    request_data = models.JSONField(_('Request Data'), default=dict, blank=True, null=True)
-    response_data = models.JSONField(_('Response Data'), default=dict, blank=True, null=True)
-    path = models.CharField(_('Path'), max_length=500, blank=False, null=False)
-    status = models.CharField(_('HTTP Status'), max_length=255, blank=False, null=False)
-    method = models.CharField(_('HTTP Method'), max_length=255, blank=False, null=False)
-    created_at = models.DateTimeField(auto_now_add=True, null=True)
-    updated_at = models.DateTimeField(auto_now=True, null=True)
-
-    class Meta:
-        abstract = True
-        ordering = ['-created_at']
-
-
-class Log(LogAbstract):
-    pass
 
 
 ## Model methods
